=========
Flowchart
=========

This cheat-sheet flowchart servers as a visual guide on how to get up and
running with memote! It is essentially the pictographic form of the section
:doc:`Getting Started <getting_started>`.

.. image:: MemoteFlowchart.png
